@@ -47,8 +47,6 @@ function cmdNotRunning() {
 function cmdNewGame() {
     state = "NEWGAME";
 
-    Settings.loadSettings();
-
     //Reset the score
     score = 0;
     scoretext.text = "Score: " + score;
@@ -112,7 +110,7 @@ function cmdDead() {
     hiscorepanel.state = "HIDDEN";
     menupanel.state = "HIDDEN"
 
-    Settings.addNewScore(level, score);
+    board.addNewScore(level, score);
     hiscorepanel.refreshScores();
 
     deadtimer.start();
@@ -174,8 +172,7 @@ function cmdStartNewLevel() {
     alienanimation.interval = alienStartSpeed;
 
     //Enable or disable the acceleromter
-    Settings.loadSettings();
-    if (Settings.UseAccelerometer == "TRUE" ) {
+    if (useAccelerometer == "TRUE" ) {
         accelerometer.start();
     } else {
         accelerometer.stop();
@@ -254,7 +251,7 @@ function destroyLivesIndication() {
 }
 
 function shipHit() {
-    if (Settings.SFX == "TRUE"){
+    if (sFX == "TRUE"){
         destroyShipSound.play();
     }
 
@@ -351,11 +348,11 @@ function fire()
     if (bullet.y > -10) {
         return;
     } else { //Reset bullet position
-        if (Settings.FlashOnFire == "TRUE") {
+        if (flashOnFire == "TRUE") {
             flashanim.start();
         }
 
-        if (Settings.SFX == "TRUE"){
+        if (sFX == "TRUE"){
             shootSound.play();
         }
         bullet.x = ship.x + ship.width/2 - bullet.width/2;
@@ -479,7 +476,7 @@ function checkBulletMysteryCollision()
     if (bullet && mysteryShip) {
         if (bullet.x > mysteryShip.x && bullet.x < mysteryShip.x + mysteryShip.width) {
             if (bullet.y > mysteryShip.y && bullet.y < mysteryShip.y + mysteryShip.height) {
-                if (Settings.SFX == "TRUE"){
+                if (sFX == "TRUE"){
                     destroyAlienSound.play();
                     mysteryShipSound.stop();
                 }
@@ -503,7 +500,7 @@ function checkBulletAlienCollision()
         if (bullet && aliens[i]) { //Check if objects exist first
             if (bullet.x > aliens[i].x && bullet.x < aliens[i].x + aliens[i].width) {
                 if ((bullet.y > aliens[i].y  || bullet.y + bullet.height > aliens[i].y) && bullet.y < aliens[i].y + aliens[i].height) {
-                    if (Settings.SFX == "TRUE"){
+                    if (sFX == "TRUE"){
                         destroyAlienSound.play();
                     }
 
@@ -738,7 +735,7 @@ function mysteryShipHandling()
             mysteryShip.x = board.width + 10;
             mysteryShip.y = closebutton.height + 5;
 
-            if (Settings.SFX == "TRUE"){
+            if (sFX == "TRUE"){
                 mysteryShipSound.play();
             }
         }
@@ -746,7 +743,7 @@ function mysteryShipHandling()
         if (mysteryShip.x > (0 - Sizer.mysteryWidth())) {
             mysteryShip.x -= 10;
         } else {
-            if (Settings.SFX == "TRUE"){
+            if (sFX == "TRUE"){
                 mysteryShipSound.stop();
             }
             mysteryShip.destroy();
